@@ -127,7 +127,7 @@ has 'TreeConfig', is => 'ro', isa => 'ArrayRef[HashRef]', lazy => 1, default =>
     my $schema = $self->app->model($model)->schema;
     
     my $require_role = $self->require_role || try{$self->configs->{$model}{require_role}};
-    my $menu_req_role = $require_role || $self->menu_require_role;
+    my $menu_req_role = $self->configs->{$model}{menu_require_role} || $require_role || $self->menu_require_role;
     
     my @children = ();
     for my $source (sort @{$s->{sources}}) {
@@ -140,6 +140,8 @@ has 'TreeConfig', is => 'ro', isa => 'ArrayRef[HashRef]', lazy => 1, default =>
       # place (note this probably needs to be fixed in there for exactly this reason)
       my $cust_merged = clone( Catalyst::Utils::merge_hashes($cust_def_config,$cust_config) );
       
+      my $local_require_role = $cust_merged->{require_role} || $require_role;
+      
       my $grid_class = $cust_merged->{grid_class} ? delete $cust_merged->{grid_class} :
         try{$self->configs->{$model}{grid_class}} || $self->table_class;
       
@@ -150,7 +152,7 @@ has 'TreeConfig', is => 'ro', isa => 'ArrayRef[HashRef]', lazy => 1, default =>
       $self->apply_init_modules( $module_name => {
         class => $grid_class,
         params => {
-          require_role => $require_role,
+          require_role => $local_require_role,
           %$cust_merged, 
           ResultSource => $Source, 
           source_model => $model . '::' . $source,
@@ -168,7 +170,7 @@ has 'TreeConfig', is => 'ro', isa => 'ArrayRef[HashRef]', lazy => 1, default =>
         params    => {},
         expand    => 1,
         children  => [],
-        require_role => $menu_req_role
+        require_role => $local_require_role
       }
     }
     
@@ -196,7 +198,8 @@ has 'TreeConfig', is => 'ro', isa => 'ArrayRef[HashRef]', lazy => 1, default =>
         tabIconCls => $iconcls,
         exclude_sources => $exclude_sources,
         header_template => $template,
-        require_role => $require_role
+        require_role => $require_role,
+        menu_require_role => $menu_req_role
       }
     });
     
